@@ -7,13 +7,11 @@
 
 #include "testpnp.h"
 
-#include "../src/config.h"
 #include "../src/configmonitor.h"
 #include "../src/edid.h"
 #include "../src/getconfigoperation.h"
 #include "../src/mode.h"
 #include "../src/output.h"
-#include "../src/screen.h"
 
 #include <QGuiApplication>
 #include <QRect>
